@@ -108,11 +108,11 @@ void Transform::dump( int indent, Context *ctx ) {
 
 	print_indent(indent);
 	printf("scaleX: "); 
-	printf("%E\n", scaleX);
+	printf("%G\n", scaleX);
 
 	print_indent(indent);
 	printf("scaleY: "); 
-	printf("%E\n", scaleY);
+	printf("%G\n", scaleY);
 
 	}
 
@@ -129,11 +129,11 @@ void Transform::dump( int indent, Context *ctx ) {
 
 	print_indent(indent);
 	printf("skewX: "); 
-	printf("%E\n", skewX);
+	printf("%G\n", skewX);
 
 	print_indent(indent);
 	printf("skewY: "); 
-	printf("%E\n", skewY);
+	printf("%G\n", skewY);
 
 	}
 
@@ -631,6 +631,19 @@ void Short::dump( int indent, Context *ctx ) {
 
 }
 
+void Float::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("Float"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("value: "); 
+}
+
 void Kerning::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -648,6 +661,10 @@ void Kerning::dump( int indent, Context *ctx ) {
 	printf("b: "); 
 	printf("%i\n", b);
 
+	print_indent(indent);
+	printf("adjustment: "); 
+	printf("%i\n", adjustment);
+
 }
 
 void WideKerning::dump( int indent, Context *ctx ) {
@@ -667,6 +684,10 @@ void WideKerning::dump( int indent, Context *ctx ) {
 	printf("b: "); 
 	printf("%i\n", b);
 
+	print_indent(indent);
+	printf("adjustment: "); 
+	printf("%i\n", adjustment);
+
 }
 
 void TextEntry::dump( int indent, Context *ctx ) {
@@ -688,6 +709,25 @@ void TextEntry::dump( int indent, Context *ctx ) {
 
 }
 
+void TextEntry2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("TextEntry2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("glyph: "); 
+	printf("%i\n", glyph);
+
+	print_indent(indent);
+	printf("advance: "); 
+	printf("%i\n", advance);
+
+}
+
 void TextRecord6::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -799,6 +839,117 @@ void TextRecord6::dump( int indent, Context *ctx ) {
 
 }
 
+void TextRecord62::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("TextRecord62"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("isSetup: "); 
+	printf("%i\n", isSetup);
+
+	if( isSetup ) {
+		
+		
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("hasFont: "); 
+	printf("%i\n", hasFont);
+
+	print_indent(indent);
+	printf("hasColor: "); 
+	printf("%i\n", hasColor);
+
+	print_indent(indent);
+	printf("hasMoveX: "); 
+	printf("%i\n", hasMoveX);
+
+	print_indent(indent);
+	printf("hasMoveY: "); 
+	printf("%i\n", hasMoveY);
+
+	if( hasFont ) {
+		
+		
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	}
+
+	if( hasColor ) {
+		
+		
+	print_indent(indent);
+	printf("color: "); 
+	printf("[Color]\n");
+	color.dump( indent+1, ctx );
+
+	}
+
+	if( hasMoveX ) {
+		
+		
+	print_indent(indent);
+	printf("x: "); 
+	printf("%i\n", x);
+
+	}
+
+	if( hasMoveY ) {
+		
+		
+	print_indent(indent);
+	printf("y: "); 
+	printf("%i\n", y);
+
+	}
+
+	if( hasFont ) {
+		
+		
+	print_indent(indent);
+	printf("fontHeight: "); 
+	printf("%i\n", fontHeight);
+
+	}
+
+	}
+
+	if( !isSetup ) {
+		
+		
+	print_indent(indent);
+	printf("nGlyphs: "); 
+	printf("%i\n", nGlyphs);
+
+	print_indent(indent);
+	printf("glyphs: "); 
+	{
+		printf("[list of TextEntry2s]\n");
+		TextEntry2 *item;
+		ListItem<TextEntry2>* i;
+		i = glyphs.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+}
+
 void TextRecord7::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -905,6 +1056,112 @@ void TextRecord7::dump( int indent, Context *ctx ) {
 
 }
 
+void TextRecord72::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("TextRecord72"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("isSetup: "); 
+	printf("%i\n", isSetup);
+
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("hasFont: "); 
+	printf("%i\n", hasFont);
+
+	print_indent(indent);
+	printf("hasColor: "); 
+	printf("%i\n", hasColor);
+
+	print_indent(indent);
+	printf("hasMoveX: "); 
+	printf("%i\n", hasMoveX);
+
+	print_indent(indent);
+	printf("hasMoveY: "); 
+	printf("%i\n", hasMoveY);
+
+	if( hasFont ) {
+		
+		
+	print_indent(indent);
+	printf("fontRef: "); 
+	printf("%i\n", fontRef);
+
+	}
+
+	if( hasColor ) {
+		
+		
+	print_indent(indent);
+	printf("color: "); 
+	printf("[Color]\n");
+	color.dump( indent+1, ctx );
+
+	}
+
+	if( hasMoveX ) {
+		
+		
+	print_indent(indent);
+	printf("x: "); 
+	printf("%i\n", x);
+
+	}
+
+	if( hasMoveY ) {
+		
+		
+	print_indent(indent);
+	printf("y: "); 
+	printf("%i\n", y);
+
+	}
+
+	if( hasFont ) {
+		
+		
+	print_indent(indent);
+	printf("fontHeight: "); 
+	printf("%i\n", fontHeight);
+
+	}
+
+	if( isSetup ) {
+		
+		
+	print_indent(indent);
+	printf("nGlyphs: "); 
+	printf("%i\n", nGlyphs);
+
+	print_indent(indent);
+	printf("glyphs: "); 
+	{
+		printf("[list of TextEntry2s]\n");
+		TextEntry2 *item;
+		ListItem<TextEntry2>* i;
+		i = glyphs.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+}
+
 void TextRecord::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -914,7 +1171,7 @@ void TextRecord::dump( int indent, Context *ctx ) {
 	printf("\n");
 	indent++;
 	
-	if( ctx->swfVersion < 7 ) {
+	if( ctx->tagVersion < 2 ) {
 		
 	print_indent(indent);
 	printf("records: "); 
@@ -934,7 +1191,7 @@ void TextRecord::dump( int indent, Context *ctx ) {
 
 	}
 
-	if( ctx->swfVersion >= 7 ) {
+	if( ctx->tagVersion >= 2 ) {
 		
 	print_indent(indent);
 	printf("string: "); 
@@ -945,6 +1202,46 @@ void TextRecord::dump( int indent, Context *ctx ) {
 
 }
 
+void TextRecord2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("TextRecord2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	if( ctx->swfVersion < 7 ) {
+		
+	print_indent(indent);
+	printf("records: "); 
+	{
+		printf("[list of TextRecord62s]\n");
+		TextRecord62 *item;
+		ListItem<TextRecord62>* i;
+		i = records.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( ctx->swfVersion >= 7 ) {
+		
+	print_indent(indent);
+	printf("textString: "); 
+	printf("[TextRecord72]\n");
+	textString.dump( indent+1, ctx );
+
+	}
+
+}
+
 void Button::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -977,8 +1274,8 @@ void Button::dump( int indent, Context *ctx ) {
 	if( hitTest || down || over || up ) {
 		
 	print_indent(indent);
-	printf("button: "); 
-	printf("%i\n", button);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
 
 	print_indent(indent);
 	printf("depth: "); 
@@ -989,6 +1286,8 @@ void Button::dump( int indent, Context *ctx ) {
 	printf("[Transform]\n");
 	transform.dump( indent+1, ctx );
 
+	if( ctx->tagVersion >= 2 ) {
+		
 	print_indent(indent);
 	printf("colorTransform: "); 
 	printf("[ColorTransform2]\n");
@@ -996,6 +1295,53 @@ void Button::dump( int indent, Context *ctx ) {
 
 	}
 
+	}
+
+}
+
+void Event::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("Event"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("flags1: "); 
+	printf("%i\n", flags1);
+
+	if( ctx->swfVersion>=6 ) {
+		
+	print_indent(indent);
+	printf("flags2: "); 
+	printf("%i\n", flags2);
+
+	}
+
+	if( (flags1 | flags2) ) {
+		
+	print_indent(indent);
+	printf("actionLength: "); 
+	print_indent(indent);
+	printf("actions: "); 
+	{
+		printf("[list of Actions]\n");
+		Action *item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
 }
 
 void Condition::dump( int indent, Context *ctx ) {
@@ -1011,14 +1357,6 @@ void Condition::dump( int indent, Context *ctx ) {
 	printf("next: "); 
 	printf("%i\n", next);
 
-	print_indent(indent);
-	printf("key: "); 
-	printf("%i\n", key);
-
-	print_indent(indent);
-	printf("menuLeave: "); 
-	printf("%i\n", menuLeave);
-
 	print_indent(indent);
 	printf("menuEnter: "); 
 	printf("%i\n", menuEnter);
@@ -1051,6 +1389,14 @@ void Condition::dump( int indent, Context *ctx ) {
 	printf("pointerEnter: "); 
 	printf("%i\n", pointerEnter);
 
+	print_indent(indent);
+	printf("key: "); 
+	printf("%i\n", key);
+
+	print_indent(indent);
+	printf("menuLeave: "); 
+	printf("%i\n", menuLeave);
+
 	print_indent(indent);
 	printf("actions: "); 
 	{
@@ -1069,6 +1415,491 @@ void Condition::dump( int indent, Context *ctx ) {
 
 }
 
+void UnknownFilter::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //-1);
+	
+	
+	printf("UnknownFilter"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("data: "); 
+	printf("(length %i)\n", len );
+	if( len && data != NULL ) {
+		int i=0;
+		while( i<len ) {
+			print_indent( indent+1 );
+			for( int n=0; n<8 && i<len; n++ ) {
+				printf(" %02X",  data[i] );
+				i++;
+			}
+			printf("\n");
+		}
+	}
+
+}
+
+void DropShadow::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x00);
+	
+	
+	printf("DropShadow"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("color: "); 
+	printf("[Color]\n");
+	color.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("angle: "); 
+	printf("%G\n", angle);
+
+	print_indent(indent);
+	printf("distance: "); 
+	printf("%G\n", distance);
+
+	print_indent(indent);
+	printf("strength: "); 
+	printf("%G\n", strength);
+
+	print_indent(indent);
+	printf("innerShadow: "); 
+	printf("%i\n", innerShadow);
+
+	print_indent(indent);
+	printf("knockout: "); 
+	printf("%i\n", knockout);
+
+	print_indent(indent);
+	printf("compositeSource: "); 
+	printf("%i\n", compositeSource);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+}
+
+void Blur::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x01);
+	
+	
+	printf("Blur"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+	print_indent(indent);
+	printf("reserved1: "); 
+	printf("%i\n", reserved1);
+
+}
+
+void Glow::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x02);
+	
+	
+	printf("Glow"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("color: "); 
+	printf("[Color]\n");
+	color.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("strength: "); 
+	printf("%G\n", strength);
+
+	print_indent(indent);
+	printf("innerGlow: "); 
+	printf("%i\n", innerGlow);
+
+	print_indent(indent);
+	printf("knockout: "); 
+	printf("%i\n", knockout);
+
+	print_indent(indent);
+	printf("compositeSource: "); 
+	printf("%i\n", compositeSource);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+}
+
+void Bevel::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x03);
+	
+	
+	printf("Bevel"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("shadowColor: "); 
+	printf("[Color]\n");
+	shadowColor.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("highlightColor: "); 
+	printf("[Color]\n");
+	highlightColor.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("angle: "); 
+	printf("%G\n", angle);
+
+	print_indent(indent);
+	printf("distance: "); 
+	printf("%G\n", distance);
+
+	print_indent(indent);
+	printf("strength: "); 
+	printf("%G\n", strength);
+
+	print_indent(indent);
+	printf("innerShadow: "); 
+	printf("%i\n", innerShadow);
+
+	print_indent(indent);
+	printf("knockout: "); 
+	printf("%i\n", knockout);
+
+	print_indent(indent);
+	printf("compositeSource: "); 
+	printf("%i\n", compositeSource);
+
+	print_indent(indent);
+	printf("onTop: "); 
+	printf("%i\n", onTop);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+}
+
+void GradientGlow::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x04);
+	
+	
+	printf("GradientGlow"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("numColors: "); 
+	printf("%i\n", numColors);
+
+	print_indent(indent);
+	printf("colors: "); 
+	{
+		printf("[list of Colors]\n");
+		Color *item;
+		ListItem<Color>* i;
+		i = colors.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("ratio: "); 
+	{
+		printf("[list of UChars]\n");
+		UChar *item;
+		ListItem<UChar>* i;
+		i = ratio.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("angle: "); 
+	printf("%G\n", angle);
+
+	print_indent(indent);
+	printf("distance: "); 
+	printf("%G\n", distance);
+
+	print_indent(indent);
+	printf("strength: "); 
+	printf("%G\n", strength);
+
+	print_indent(indent);
+	printf("innerGlow: "); 
+	printf("%i\n", innerGlow);
+
+	print_indent(indent);
+	printf("knockout: "); 
+	printf("%i\n", knockout);
+
+	print_indent(indent);
+	printf("compositeSource: "); 
+	printf("%i\n", compositeSource);
+
+	print_indent(indent);
+	printf("onTop: "); 
+	printf("%i\n", onTop);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+}
+
+void Convolution::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x05);
+	
+	
+	printf("Convolution"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("matrixX: "); 
+	printf("%i\n", matrixX);
+
+	print_indent(indent);
+	printf("matrixY: "); 
+	printf("%i\n", matrixY);
+
+	print_indent(indent);
+	printf("divizor: "); 
+	print_indent(indent);
+	printf("bias: "); 
+	print_indent(indent);
+	printf("matrix: "); 
+	{
+		printf("[list of Floats]\n");
+		Float *item;
+		ListItem<Float>* i;
+		i = matrix.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("defaultColor: "); 
+	printf("[Color]\n");
+	defaultColor.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("clamp: "); 
+	printf("%i\n", clamp);
+
+	print_indent(indent);
+	printf("preserveAlpha: "); 
+	printf("%i\n", preserveAlpha);
+
+}
+
+void ColorMatrix::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x06);
+	
+	
+	printf("ColorMatrix"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("matrix: "); 
+	{
+		printf("[list of Floats]\n");
+		Float *item;
+		ListItem<Float>* i;
+		i = matrix.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
+void GradientBevel::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x07);
+	
+	
+	printf("GradientBevel"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("numColors: "); 
+	printf("%i\n", numColors);
+
+	print_indent(indent);
+	printf("colors: "); 
+	{
+		printf("[list of Colors]\n");
+		Color *item;
+		ListItem<Color>* i;
+		i = colors.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("ratio: "); 
+	{
+		printf("[list of UChars]\n");
+		UChar *item;
+		ListItem<UChar>* i;
+		i = ratio.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("blurX: "); 
+	printf("%G\n", blurX);
+
+	print_indent(indent);
+	printf("blurY: "); 
+	printf("%G\n", blurY);
+
+	print_indent(indent);
+	printf("angle: "); 
+	printf("%G\n", angle);
+
+	print_indent(indent);
+	printf("distance: "); 
+	printf("%G\n", distance);
+
+	print_indent(indent);
+	printf("strength: "); 
+	printf("%G\n", strength);
+
+	print_indent(indent);
+	printf("innerGlow: "); 
+	printf("%i\n", innerGlow);
+
+	print_indent(indent);
+	printf("knockout: "); 
+	printf("%i\n", knockout);
+
+	print_indent(indent);
+	printf("compositeSource: "); 
+	printf("%i\n", compositeSource);
+
+	print_indent(indent);
+	printf("onTop: "); 
+	printf("%i\n", onTop);
+
+	print_indent(indent);
+	printf("passes: "); 
+	printf("%i\n", passes);
+
+}
+
 void Solid::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1207,6 +2038,50 @@ void ClippedBitmap::dump( int indent, Context *ctx ) {
 
 }
 
+void TiledBitmap2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x42);
+	
+	
+	printf("TiledBitmap2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("matrix: "); 
+	printf("[Transform]\n");
+	matrix.dump( indent+1, ctx );
+
+}
+
+void ClippedBitmap2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x43);
+	
+	
+	printf("ClippedBitmap2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("matrix: "); 
+	printf("[Transform]\n");
+	matrix.dump( indent+1, ctx );
+
+}
+
 void UnknownTag::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1405,6 +2280,57 @@ void DefineText::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineText2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x21);
+	
+	
+	printf("DefineText2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("bounds: "); 
+	printf("[Rectangle]\n");
+	bounds.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("transform: "); 
+	printf("[Transform]\n");
+	transform.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("glyphBits2: "); 
+	printf("%i\n", glyphBits2);
+
+	print_indent(indent);
+	printf("advanceBits2: "); 
+	printf("%i\n", advanceBits2);
+
+	print_indent(indent);
+	printf("records: "); 
+	{
+		printf("[list of TextRecord2s]\n");
+		TextRecord2 *item;
+		ListItem<TextRecord2>* i;
+		i = records.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
 void DoAction::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1511,6 +2437,128 @@ void DefineFontInfo::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineSound::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x0E);
+	
+	
+	printf("DefineSound"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("format: "); 
+	printf("%i\n", format);
+
+	print_indent(indent);
+	printf("rate: "); 
+	printf("%i\n", rate);
+
+	print_indent(indent);
+	printf("is16bit: "); 
+	printf("%i\n", is16bit);
+
+	print_indent(indent);
+	printf("stereo: "); 
+	printf("%i\n", stereo);
+
+	print_indent(indent);
+	printf("samples: "); 
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
+void StartSound::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x0F);
+	
+	
+	printf("StartSound"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("stopPlayback: "); 
+	printf("%i\n", stopPlayback);
+
+	print_indent(indent);
+	printf("noMultiple: "); 
+	printf("%i\n", noMultiple);
+
+	print_indent(indent);
+	printf("hasEnvelope: "); 
+	printf("%i\n", hasEnvelope);
+
+	print_indent(indent);
+	printf("hasLoop: "); 
+	printf("%i\n", hasLoop);
+
+	print_indent(indent);
+	printf("hasOutPoint: "); 
+	printf("%i\n", hasOutPoint);
+
+	print_indent(indent);
+	printf("hasInPoint: "); 
+	printf("%i\n", hasInPoint);
+
+	if( hasInPoint ) {
+		
+		
+	print_indent(indent);
+	printf("inPoint: "); 
+	}
+
+	if( hasOutPoint ) {
+		
+		
+	print_indent(indent);
+	printf("outPoint: "); 
+	}
+
+	if( hasLoop ) {
+		
+		
+	print_indent(indent);
+	printf("loop: "); 
+	printf("%i\n", loop);
+
+	}
+
+	if( hasEnvelope ) {
+		
+		
+	print_indent(indent);
+	printf("envelopeCount: "); 
+	printf("%i\n", envelopeCount);
+
+	print_indent(indent);
+	printf("envelopeData: "); 
+	printf("[Rest]\n");
+	envelopeData.dump( indent+1, ctx );
+
+	}
+
+}
+
 void DefineShape2::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1527,9 +2575,19 @@ void DefineShape2::dump( int indent, Context *ctx ) {
 	printf("%i\n", objectID);
 
 	print_indent(indent);
-	printf("data: "); 
-	printf("[Rest]\n");
-	data.dump( indent+1, ctx );
+	printf("bounds: "); 
+	printf("[Rectangle]\n");
+	bounds.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("styles: "); 
+	printf("[StyleList]\n");
+	styles.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("shapes: "); 
+	printf("[Shape]\n");
+	shapes.dump( indent+1, ctx );
 
 }
 
@@ -1565,6 +2623,50 @@ void DefineShape3::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineShape4::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x43);
+	
+	
+	printf("DefineShape4"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
+void DefineShape5::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x53);
+	
+	
+	printf("DefineShape5"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
 void DefineMorphShape::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1778,6 +2880,30 @@ void DefineBitsJPEG2::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineBitsJPEG3::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x23);
+	
+	
+	printf("DefineBitsJPEG3"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("offset_to_alpha: "); 
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
 void DefineBitsLossless2::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1805,6 +2931,14 @@ void DefineBitsLossless2::dump( int indent, Context *ctx ) {
 	printf("height: "); 
 	printf("%i\n", height);
 
+	if( format==3 ) {
+		
+	print_indent(indent);
+	printf("n_colormap: "); 
+	printf("%i\n", n_colormap);
+
+	}
+
 	print_indent(indent);
 	printf("data: "); 
 	printf("[Rest]\n");
@@ -1918,10 +3052,37 @@ void PlaceObject2::dump( int indent, Context *ctx ) {
 	if( hasEventHandler ) {
 		
 		
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("allflags1: "); 
+	printf("%i\n", allflags1);
+
+	if( ctx->swfVersion>=6 ) {
+		
+	print_indent(indent);
+	printf("allflags2: "); 
+	printf("%i\n", allflags2);
+
+	}
+
 	print_indent(indent);
 	printf("events: "); 
-	printf("[Rest]\n");
-	events.dump( indent+1, ctx );
+	{
+		printf("[list of Events]\n");
+		Event *item;
+		ListItem<Event>* i;
+		i = events.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
 
 	}
 
@@ -2233,9 +3394,9 @@ void DefineFont::dump( int indent, Context *ctx ) {
 	printf("%i\n", objectID);
 
 	print_indent(indent);
-	printf("glyphs: "); 
-	printf("[GlyphList]\n");
-	glyphs.dump( indent+1, ctx );
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
 
 }
 
@@ -2400,6 +3561,55 @@ void DefineFont2::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineButton::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x07);
+	
+	
+	printf("DefineButton"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("buttons: "); 
+	{
+		printf("[list of Buttons]\n");
+		Button *item;
+		ListItem<Button>* i;
+		i = buttons.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	print_indent(indent);
+	printf("actions: "); 
+	{
+		printf("[list of Actions]\n");
+		Action *item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
 void DefineButton2::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -2663,6 +3873,445 @@ void VideoFrame::dump( int indent, Context *ctx ) {
 
 }
 
+void ScriptLimits::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x41);
+	
+	
+	printf("ScriptLimits"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("maxRecursionDepth: "); 
+	printf("%i\n", maxRecursionDepth);
+
+	print_indent(indent);
+	printf("timeout: "); 
+	printf("%i\n", timeout);
+
+}
+
+void SetTabIndex::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x42);
+	
+	
+	printf("SetTabIndex"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("depth: "); 
+	printf("%i\n", depth);
+
+	print_indent(indent);
+	printf("tabIndex: "); 
+	printf("%i\n", tabIndex);
+
+}
+
+void PlaceObject3::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x46);
+	
+	
+	printf("PlaceObject3"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("hasEventHandler: "); 
+	printf("%i\n", hasEventHandler);
+
+	print_indent(indent);
+	printf("hasClipDepth: "); 
+	printf("%i\n", hasClipDepth);
+
+	print_indent(indent);
+	printf("hasName: "); 
+	printf("%i\n", hasName);
+
+	print_indent(indent);
+	printf("hasMorph: "); 
+	printf("%i\n", hasMorph);
+
+	print_indent(indent);
+	printf("hasColorTransform: "); 
+	printf("%i\n", hasColorTransform);
+
+	print_indent(indent);
+	printf("hasTransform: "); 
+	printf("%i\n", hasTransform);
+
+	print_indent(indent);
+	printf("hasID: "); 
+	printf("%i\n", hasID);
+
+	print_indent(indent);
+	printf("replace: "); 
+	printf("%i\n", replace);
+
+	print_indent(indent);
+	printf("reserved1: "); 
+	printf("%i\n", reserved1);
+
+	print_indent(indent);
+	printf("hasCacheAsBitmap: "); 
+	printf("%i\n", hasCacheAsBitmap);
+
+	print_indent(indent);
+	printf("hasBlendMode: "); 
+	printf("%i\n", hasBlendMode);
+
+	print_indent(indent);
+	printf("hasFilterList: "); 
+	printf("%i\n", hasFilterList);
+
+	print_indent(indent);
+	printf("depth: "); 
+	printf("%i\n", depth);
+
+	if( hasID ) {
+		
+		
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	}
+
+	if( hasTransform ) {
+		
+		
+	print_indent(indent);
+	printf("transform: "); 
+	printf("[Transform]\n");
+	transform.dump( indent+1, ctx );
+
+	}
+
+	if( hasColorTransform ) {
+		
+		
+	print_indent(indent);
+	printf("colorTransform: "); 
+	printf("[ColorTransform2]\n");
+	colorTransform.dump( indent+1, ctx );
+
+	}
+
+	if( hasMorph ) {
+		
+		
+	print_indent(indent);
+	printf("morph: "); 
+	printf("%i\n", morph);
+
+	}
+
+	if( hasName ) {
+		
+		
+	print_indent(indent);
+	printf("name: "); 
+	printf("%s\n", name?name:"(nil)");
+
+	}
+
+	if( hasClipDepth ) {
+		
+		
+	print_indent(indent);
+	printf("clipDepth: "); 
+	printf("%i\n", clipDepth);
+
+	}
+
+	if( hasFilterList ) {
+		
+		
+	print_indent(indent);
+	printf("numFilters: "); 
+	printf("%i\n", numFilters);
+
+	print_indent(indent);
+	printf("filters: "); 
+	{
+		printf("[list of Filters]\n");
+		Filter *item;
+		ListItem<Filter>* i;
+		i = filters.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( hasBlendMode ) {
+		
+		
+	print_indent(indent);
+	printf("blendMode: "); 
+	printf("%i\n", blendMode);
+
+	}
+
+	if( hasCacheAsBitmap ) {
+		
+		
+	print_indent(indent);
+	printf("bitmapCaching: "); 
+	printf("%i\n", bitmapCaching);
+
+	}
+
+	if( hasEventHandler ) {
+		
+		
+	print_indent(indent);
+	printf("reserved: "); 
+	printf("%i\n", reserved);
+
+	print_indent(indent);
+	printf("allflags1: "); 
+	printf("%i\n", allflags1);
+
+	if( ctx->swfVersion>=6 ) {
+		
+	print_indent(indent);
+	printf("allflags2: "); 
+	printf("%i\n", allflags2);
+
+	}
+
+	print_indent(indent);
+	printf("events: "); 
+	{
+		printf("[list of Events]\n");
+		Event *item;
+		ListItem<Event>* i;
+		i = events.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+}
+
+void ImportAssets2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x47);
+	
+	
+	printf("ImportAssets2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("url: "); 
+	printf("%s\n", url?url:"(nil)");
+
+	print_indent(indent);
+	printf("reserved1: "); 
+	printf("%i\n", reserved1);
+
+	print_indent(indent);
+	printf("reserved2: "); 
+	printf("%i\n", reserved2);
+
+	print_indent(indent);
+	printf("count: "); 
+	printf("%i\n", count);
+
+	print_indent(indent);
+	printf("symbols: "); 
+	{
+		printf("[list of Symbols]\n");
+		Symbol *item;
+		ListItem<Symbol>* i;
+		i = symbols.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
+void FileAttributes::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x45);
+	
+	
+	printf("FileAttributes"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("reserved1: "); 
+	printf("%i\n", reserved1);
+
+	print_indent(indent);
+	printf("hasMetaData: "); 
+	printf("%i\n", hasMetaData);
+
+	print_indent(indent);
+	printf("reserved2: "); 
+	printf("%i\n", reserved2);
+
+	print_indent(indent);
+	printf("useNetwork: "); 
+	printf("%i\n", useNetwork);
+
+	print_indent(indent);
+	printf("reserved3: "); 
+	printf("%i\n", reserved3);
+
+}
+
+void DefineFontInfo3::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x49);
+	
+	
+	printf("DefineFontInfo3"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
+void CSMTextSettings::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x4A);
+	
+	
+	printf("CSMTextSettings"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("useFlashType: "); 
+	printf("%i\n", useFlashType);
+
+	print_indent(indent);
+	printf("gridFit: "); 
+	printf("%i\n", gridFit);
+
+	print_indent(indent);
+	printf("reserved1: "); 
+	printf("%i\n", reserved1);
+
+	print_indent(indent);
+	printf("thickness: "); 
+	print_indent(indent);
+	printf("sharpness: "); 
+	print_indent(indent);
+	printf("reserved2: "); 
+	printf("%i\n", reserved2);
+
+}
+
+void DefineFont3::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x4B);
+	
+	
+	printf("DefineFont3"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
+void Metadata::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x4D);
+	
+	
+	printf("Metadata"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("RDF: "); 
+}
+
+void DefineScalingGrid::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x4E);
+	
+	
+	printf("DefineScalingGrid"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("splitter: "); 
+	printf("[Rectangle]\n");
+	splitter.dump( indent+1, ctx );
+
+}
+
 void StackString::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
