@@ -6,6 +6,316 @@
 namespace SWF {
 
 
+size_t UnknownFilter::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += len * 8;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("UnknownFilter sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DropShadow::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += color.getSize(ctx,r);
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 16;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 5;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("DropShadow sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t Blur::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 32;
+
+	r += 32;
+
+	r += 5;
+
+	r += 3;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("Blur sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t Glow::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += color.getSize(ctx,r);
+
+	r += 32;
+
+	r += 32;
+
+	r += 16;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 5;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("Glow sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t Bevel::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += shadowColor.getSize(ctx,r);
+
+	r += highlightColor.getSize(ctx,r);
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 16;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 4;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("Bevel sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t GradientGlow::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += 8;
+
+	{
+		Color* item;
+		ListItem<Color>* i;
+		i = colors.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	{
+		UChar* item;
+		ListItem<UChar>* i;
+		i = ratio.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 16;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 4;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("GradientGlow sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t Convolution::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += 8;
+
+	r += 8;
+
+	r += 32;
+
+	r += 32;
+
+	{
+		Float* item;
+		ListItem<Float>* i;
+		i = matrix.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	r += defaultColor.getSize(ctx,r);
+
+	r += 5;
+
+	r++;
+
+	r++;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("Convolution sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t ColorMatrix::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	{
+		Float* item;
+		ListItem<Float>* i;
+		i = matrix.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("ColorMatrix sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t GradientBevel::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 1;
+
+	r += 8;
+
+	{
+		Color* item;
+		ListItem<Color>* i;
+		i = colors.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	{
+		UChar* item;
+		ListItem<UChar>* i;
+		i = ratio.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 32;
+
+	r += 16;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 4;
+
+
+	r += Filter::getHeaderSize( r-start_at );
+//	printf("GradientBevel sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t Solid::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -100,6 +410,34 @@ size_t ClippedBitmap::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t TiledBitmap2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += matrix.getSize(ctx,r);
+
+
+	r += Style::getHeaderSize( r-start_at );
+//	printf("TiledBitmap2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t ClippedBitmap2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += matrix.getSize(ctx,r);
+
+
+	r += Style::getHeaderSize( r-start_at );
+//	printf("ClippedBitmap2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t UnknownTag::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -139,6 +477,8 @@ size_t DefineShape::calcSize( Context *ctx, int start_at ) {
 
 	ctx->many_shapes = 0;
 
+	ctx->tagVersion = 1;
+
 	r += 16;
 
 	r += bounds.getSize(ctx,r);
@@ -217,6 +557,8 @@ size_t DefineText::calcSize( Context *ctx, int start_at ) {
 
 	ctx->alpha = 0;
 
+	ctx->tagVersion = 1;
+
 	{
 		TextRecord* item;
 		ListItem<TextRecord>* i;
@@ -237,6 +579,45 @@ size_t DefineText::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t DefineText2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->glyphBits2 = glyphBits2;
+
+	ctx->advanceBits2 = advanceBits2;
+
+	ctx->alpha = 1;
+
+	r += 16;
+
+	r += bounds.getSize(ctx,r);
+
+	r += transform.getSize(ctx,r);
+
+	r += 8;
+
+	r += 8;
+
+	{
+		TextRecord2* item;
+		ListItem<TextRecord2>* i;
+		i = records.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineText2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t DoAction::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -298,14 +679,106 @@ size_t DefineFontInfo::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
-size_t DefineShape2::calcSize( Context *ctx, int start_at ) {
+size_t DefineSound::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
 	r += 16;
 
+	r += 4;
+
+	r += 2;
+
+	r++;
+
+	r++;
+
+	r += 32;
+
 	r += data.getSize(ctx,r);
 
 
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineSound sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t StartSound::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += 2;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	if( hasInPoint ) {
+		
+		
+	r += 32;
+
+	}
+
+	if( hasOutPoint ) {
+		
+		
+	r += 32;
+
+	}
+
+	if( hasLoop ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasEnvelope ) {
+		
+		
+	r += 8;
+
+	r += envelopeData.getSize(ctx,r);
+
+	}
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("StartSound sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DefineShape2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->alpha = 0;
+
+	ctx->many_shapes = 1;
+
+	ctx->tagVersion = 2;
+
+	r += 16;
+
+	r += bounds.getSize(ctx,r);
+
+	r += styles.getSize(ctx,r);
+
+	r += shapes.getSize(ctx,r);
+
+	if( r%8 != 0 ) r += 8-(r%8);
+
+
 	r += Tag::getHeaderSize( r-start_at );
 //	printf("DefineShape2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
 
@@ -319,6 +792,8 @@ size_t DefineShape3::calcSize( Context *ctx, int start_at ) {
 
 	ctx->many_shapes = 1;
 
+	ctx->tagVersion = 3;
+
 	r += 16;
 
 	r += bounds.getSize(ctx,r);
@@ -336,6 +811,34 @@ size_t DefineShape3::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t DefineShape4::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += data.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineShape4 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DefineShape5::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += data.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineShape5 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t DefineMorphShape::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -456,6 +959,22 @@ size_t DefineBitsJPEG2::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t DefineBitsJPEG3::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += 32;
+
+	r += data.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineBitsJPEG3 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t DefineBitsLossless2::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -467,6 +986,12 @@ size_t DefineBitsLossless2::calcSize( Context *ctx, int start_at ) {
 
 	r += 16;
 
+	if( format==3 ) {
+		
+	r += 8;
+
+	}
+
 	r += data.getSize(ctx,r);
 
 
@@ -542,7 +1067,28 @@ size_t PlaceObject2::calcSize( Context *ctx, int start_at ) {
 	if( hasEventHandler ) {
 		
 		
-	r += events.getSize(ctx,r);
+	r += 16;
+
+	r += 16;
+
+	if( ctx->swfVersion>=6 ) {
+		
+	r += 16;
+
+	}
+
+	{
+		Event* item;
+		ListItem<Event>* i;
+		i = events.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
 
 	}
 
@@ -744,7 +1290,7 @@ size_t DefineFont::calcSize( Context *ctx, int start_at ) {
 
 	r += 16;
 
-	r += glyphs.getSize(ctx,r);
+	r += data.getSize(ctx,r);
 
 
 	r += Tag::getHeaderSize( r-start_at );
@@ -872,9 +1418,51 @@ size_t DefineFont2::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t DefineButton::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	ctx->tagVersion = 1;
+
+	r += 16;
+
+	{
+		Button* item;
+		ListItem<Button>* i;
+		i = buttons.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	{
+		Action* item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineButton sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t DefineButton2::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
+	ctx->tagVersion = 2;
+
 	r += 16;
 
 	r += 7;
@@ -1047,6 +1635,303 @@ size_t VideoFrame::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t ScriptLimits::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += 16;
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("ScriptLimits sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t SetTabIndex::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += 16;
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("SetTabIndex sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t PlaceObject3::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 5;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 16;
+
+	if( hasID ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasTransform ) {
+		
+		
+	r += transform.getSize(ctx,r);
+
+	}
+
+	if( hasColorTransform ) {
+		
+		
+	r += colorTransform.getSize(ctx,r);
+
+	}
+
+	if( hasMorph ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasName ) {
+		
+		
+	r += ((name ? strlen( name ) : 0)+1)*8;
+
+	}
+
+	if( hasClipDepth ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasFilterList ) {
+		
+		
+	r += 8;
+
+	{
+		Filter* item;
+		ListItem<Filter>* i;
+		i = filters.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( hasBlendMode ) {
+		
+		
+	r += 8;
+
+	}
+
+	if( hasCacheAsBitmap ) {
+		
+		
+	r += 8;
+
+	}
+
+	if( hasEventHandler ) {
+		
+		
+	r += 16;
+
+	r += 16;
+
+	if( ctx->swfVersion>=6 ) {
+		
+	r += 16;
+
+	}
+
+	{
+		Event* item;
+		ListItem<Event>* i;
+		i = events.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("PlaceObject3 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t ImportAssets2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += ((url ? strlen( url ) : 0)+1)*8;
+
+	r += 8;
+
+	r += 8;
+
+	r += 16;
+
+	{
+		Symbol* item;
+		ListItem<Symbol>* i;
+		i = symbols.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("ImportAssets2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t FileAttributes::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 3;
+
+	r++;
+
+	r += 3;
+
+	r++;
+
+	r += 24;
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("FileAttributes sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DefineFontInfo3::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += data.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineFontInfo3 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t CSMTextSettings::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += 2;
+
+	r += 3;
+
+	r += 3;
+
+	r += 32;
+
+	r += 32;
+
+	r += 8;
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("CSMTextSettings sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DefineFont3::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += data.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineFont3 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t Metadata::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += ((RDF ? strlen( RDF ) : 0)+1)*8;
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("Metadata sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
+size_t DefineScalingGrid::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+	
+	r += 16;
+
+	r += splitter.getSize(ctx,r);
+
+
+	r += Tag::getHeaderSize( r-start_at );
+//	printf("DefineScalingGrid sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t StackString::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
@@ -2540,7 +3425,11 @@ size_t StyleList::calcSize( Context *ctx, int start_at ) {
 
 	ctx->lineBits = lineBits;
 
-	r += 8;
+    if( n_fillStyles >= 255 ) {
+        r += 24;
+    } else {
+    	r += 8;
+    }
 
 	{
 		Style* item;
@@ -2555,7 +3444,11 @@ size_t StyleList::calcSize( Context *ctx, int start_at ) {
 		}
 	}
 
-	r += 8;
+    if( n_lineStyles >= 255 ) {
+        r += 24;
+    } else {
+    	r += 8;
+    }
 
 	{
 		LineStyle* item;
@@ -2720,10 +3613,8 @@ size_t GlyphShape::calcSize( Context *ctx, int start_at ) {
 			i = i->next();
 		}
 	}
-fillBits = SWFBitsNeeded( 1 );
-		ctx->fillBits = fillBits;
-	lineBits = SWFBitsNeeded( 0 );
-		ctx->lineBits = lineBits;
+fillBits =1;
+	lineBits =0;
 	
 
 //	printf("GlyphShape sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
@@ -2835,6 +3726,20 @@ size_t Short::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t Float::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	r += 32;
+
+
+//	printf("Float sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t Kerning::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
@@ -2845,6 +3750,8 @@ size_t Kerning::calcSize( Context *ctx, int start_at ) {
 
 	r += 8;
 
+	r += 16;
+
 
 //	printf("Kerning sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
 
@@ -2861,6 +3768,8 @@ size_t WideKerning::calcSize( Context *ctx, int start_at ) {
 
 	r += 16;
 
+	r += 16;
+
 
 //	printf("WideKerning sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
 
@@ -2883,6 +3792,22 @@ size_t TextEntry::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t TextEntry2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	r += ctx->glyphBits2;
+
+	r += ctx->advanceBits2;
+
+
+//	printf("TextEntry2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t TextRecord6::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
@@ -2969,6 +3894,92 @@ size_t TextRecord6::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t TextRecord62::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	r++;
+
+	if( isSetup ) {
+		
+		
+	r += 3;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	if( hasFont ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasColor ) {
+		
+		
+	r += color.getSize(ctx,r);
+
+	}
+
+	if( hasMoveX ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasMoveY ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasFont ) {
+		
+		
+	r += 16;
+
+	}
+
+	}
+
+	if( !isSetup ) {
+		
+		
+	r += 7;
+
+	{
+		TextEntry2* item;
+		ListItem<TextEntry2>* i;
+		i = glyphs.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	if( r%8 != 0 ) r += 8-(r%8);
+
+	}
+
+
+//	printf("TextRecord62 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t TextRecord7::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
@@ -3050,13 +4061,96 @@ size_t TextRecord7::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t TextRecord72::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	ctx->alpha = 1;
+
+	r++;
+
+	r += 3;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	if( hasFont ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasColor ) {
+		
+		
+	r += color.getSize(ctx,r);
+
+	}
+
+	if( hasMoveX ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasMoveY ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( hasFont ) {
+		
+		
+	r += 16;
+
+	}
+
+	if( isSetup ) {
+		
+		
+	r += 8;
+
+	{
+		TextEntry2* item;
+		ListItem<TextEntry2>* i;
+		i = glyphs.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( r%8 != 0 ) r += 8-(r%8);
+
+
+//	printf("TextRecord72 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t TextRecord::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
 	r += Item::getHeaderSize( r-start_at );
 
 	
-	if( ctx->swfVersion < 7 ) {
+	if( ctx->tagVersion < 2 ) {
 		
 	{
 		TextRecord6* item;
@@ -3073,7 +4167,7 @@ size_t TextRecord::calcSize( Context *ctx, int start_at ) {
 
 	}
 
-	if( ctx->swfVersion >= 7 ) {
+	if( ctx->tagVersion >= 2 ) {
 		
 	r += string.getSize(ctx,r);
 
@@ -3085,6 +4179,41 @@ size_t TextRecord::calcSize( Context *ctx, int start_at ) {
 	return r-start_at;
 }
 
+size_t TextRecord2::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	if( ctx->swfVersion < 7 ) {
+		
+	{
+		TextRecord62* item;
+		ListItem<TextRecord62>* i;
+		i = records.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( ctx->swfVersion >= 7 ) {
+		
+	r += textString.getSize(ctx,r);
+
+	}
+
+
+//	printf("TextRecord2 sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t Button::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
@@ -3109,16 +4238,61 @@ size_t Button::calcSize( Context *ctx, int start_at ) {
 
 	r += transform.getSize(ctx,r);
 
+	if( ctx->tagVersion >= 2 ) {
+		
 	r += colorTransform.getSize(ctx,r);
 
 	}
 
+	}
+
 
 //	printf("Button sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
 
 	return r-start_at;
 }
 
+size_t Event::calcSize( Context *ctx, int start_at ) {
+	size_t r = start_at;
+
+	r += Item::getHeaderSize( r-start_at );
+
+	
+	if( r%8 != 0 ) r += 8-(r%8);
+
+	r += 16;
+
+	if( ctx->swfVersion>=6 ) {
+		
+	r += 16;
+
+	}
+
+	if( (flags1 | flags2) ) {
+		
+	r += 32;
+
+	{
+		Action* item;
+		ListItem<Action>* i;
+		i = actions.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+
+//	printf("Event sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
+
+	return r-start_at;
+}
+
 size_t Condition::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 
@@ -3127,26 +4301,26 @@ size_t Condition::calcSize( Context *ctx, int start_at ) {
 	
 	r += 16;
 
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
 	r += 7;
 
 	r++;
 
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
-	r++;
-
 	{
 		Action* item;
 		ListItem<Action>* i;
